# ReinstatementResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**reinstatement_reference_number** | **str** |  | 
**permit_reference_number** | **str** |  | [optional] 
**reinstatement_status** | [**ReinstatementStatusResponse**](ReinstatementStatusResponse.md) |  | 
**reinstatement_status_string** | **str** |  | 
**reinstatement_date** | **datetime** |  | [optional] 
**depth** | **float** |  | [optional] 
**length** | **float** |  | [optional] 
**width** | **float** |  | [optional] 
**reinstatement_coordinates** | **object** |  | 
**secondary_reinstatement_coordinates** | **object** |  | [optional] 
**location_description** | **str** |  | 
**end_date** | **datetime** |  | [optional] 
**date_created** | **datetime** |  | 
**date_modified** | **datetime** |  | 
**location_types** | [**list[LocationTypeResponse]**](LocationTypeResponse.md) |  | 
**location_types_string** | **list[str]** |  | 
**reinstatement_evidence** | **bool** |  | 
**files** | [**list[FileSummaryResponse]**](FileSummaryResponse.md) |  | [optional] 
**number_of_holes** | **float** |  | [optional] 
**is_active_reinstatement** | **bool** |  | 
**response_to_remedial_works** | **bool** |  | [optional] 
**base_courses_affected** | **bool** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

